# log_everywhere Python API

<p align="center">
  <a href="https://github.com/Shail-Shouryya/log_everywhere/blob/master/LICENSE"><img alt="GitHub license" src="https://img.shields.io/github/license/Shail-Shouryya/log_everywhere?color=yellow&labelColor=black"></a>
  <a href="https://docs.python.org/3/index.html">    <img src="https://img.shields.io/badge/python-3.6%2B-blue?labelColor=black"/></a>
  <a href="https://www.python.org/dev/peps/pep-0008"><img src="https://img.shields.io/badge/code%20style-PEP8-yellow.svg?labelColor=black"/></a>
  <a href="https://github.com/Shail-Shouryya/log_everywhere/stargazers"><img alt="GitHub stars" src="https://img.shields.io/github/stars/Shail-Shouryya/log_everywhere?color=blue&labelColor=black"></a>
  <a href="https://github.com/Shail-Shouryya/log_everywhere/network"><img alt="GitHub forks" src="https://img.shields.io/github/forks/Shail-Shouryya/log_everywhere?color=yellow&labelColor=black"></a>
  <br>
  <a href="https://badge.fury.io/py/log-everywhere"><img src="https://badge.fury.io/py/log-everywhere.svg" alt="PyPI version" height="20"></a>
  <br>
  <a href="https://pypi.org/project/log-everywhere/"><img alt="PyPI - Wheel" src="https://img.shields.io/pypi/wheel/log_everywhere?labelColor=black&label=PyPI%20-%20Wheel"></a>
  <a href="https://pypi.org/project/log-everywhere/#files/"><img alt="PyPI - Format" src="https://img.shields.io/pypi/format/log_everywhere?labelColor=black&label=PyPI%20-%20Format"></a>
  <a href="https://pypi.org/project/log-everywhere/#history/"><img alt="PyPI - Status" src="https://img.shields.io/pypi/status/log_everywhere?labelColor=black&label=PyPI%20-%20Status"></a>
  <br>
  <a href="https://pypi.org/project/log-everywhere/"><img alt="PyPI - Implementation" src="https://img.shields.io/pypi/implementation/log_everywhere?labelColor=black&label=PyPI%20-%20Implementation"></a>
  <a href="https://pypi.org/project/log-everywhere/"><img alt="PyPI - Python Version" src="https://img.shields.io/pypi/pyversions/log_everywhere?labelColor=black&label=PyPI%20-%20Python%20Version"></a>
  <br>
  <a href="https://codebeat.co/projects/github-com-shail-shouryya-log_everywhere-master"><img src="https://codebeat.co/badges/46b103ed-da79-4893-96af-ce95c9149532" alt="codebeat badge"/></a>
</p>

<details>
  <summary><b>Usage Statistics</b></summary>

- [PePy](https://pepy.tech/project/log-everywhere)
- [PyPi Stats](https://pypistats.org/packages/log-everywhere)
</details>
<p>
  <a href="https://pypistats.org/packages/log-everywhere"><img alt="PyPI - Daily Downloads" src="https://img.shields.io/pypi/dd/log_everywhere?labelColor=black&color=blue&label=PyPI%20downloads"></a>
  <br>
  <a href="https://pypistats.org/packages/log-everywhere"><img alt="PyPI - Weekly Downloads" src="https://img.shields.io/pypi/dw/log_everywhere?labelColor=black&color=yellow&label=PyPI%20downloads"></a>
  <a href="https://pepy.tech/project/log-everywhere"><img alt="PePY Weekly Downloads" src="https://static.pepy.tech/personalized-badge/log-everywhere?period=week&units=international_system&left_color=black&right_color=blue&left_text=PePY%20Downloads/week"></a>
  <br>
  <a href="https://pypistats.org/packages/log-everywhere"><img alt="PyPI - Monthly Downloads" src="https://img.shields.io/pypi/dm/log_everywhere?labelColor=black&color=blue&label=PyPI%20downloads"></a>
  <a href="https://pepy.tech/project/log-everywhere"><img alt="PePY Monthly Downloads" src="https://static.pepy.tech/personalized-badge/log-everywhere?period=month&units=international_system&left_color=black&right_color=yellow&left_text=PePY%20Downloads/month"></a>
  <br>
  <a href="https://pepy.tech/project/log-everywhere"><img alt="PePY Total Downloads" src="https://static.pepy.tech/personalized-badge/log-everywhere?period=total&units=international_system&left_color=black&right_color=yellow&left_text=PePY%20Downloads%20Total"></a>
</p>
